~~~~~~~~~~~~~~
epub-extractor
~~~~~~~~~~~~~~

* Extract Jpeg images from EPUB file.

* Dump metadata from EPUB file.


Install
-------

::

  $ pip install epub-extractor


Requirements
------------

* unzip



epub-extract-jpeg
-----------------

::

    $ epub-extract-jpeg comic.epub

Extract jpeg images.



epub-dump-meta
--------------

::

    $ epub-extract-jpeg comic.epub

